summary refs log tree commit diff stats
path: root/gmi2htmldir.sh
diff options
context:
space:
mode:
Diffstat (limited to 'gmi2htmldir.sh')
-rwxr-xr-xgmi2htmldir.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/gmi2htmldir.sh b/gmi2htmldir.sh
index 67b8c3c..6359dd0 100755
--- a/gmi2htmldir.sh
+++ b/gmi2htmldir.sh
@@ -18,19 +18,19 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 # usage:
-#   $ ./gmi2htmldir.sh <in> <out> title=<title> css=<css> url=<url>
+#   $ ./gmi2htmldir.sh <in> <out> title=<title> css=<css> original=<original>
 #
 # parameters:
 #   <in>: the folder of Gemini files to be converted
 #   <out>: the folder in which to put the generated HTML files
 #   <title>, <css>, <url>: parameters passed to gmi2html.awk; see gmi2html.awk for more details
 #
 
 in=$1
 out=$2
 title=$3
 css=$4
-url=$5
+original=$5
 
 # Get the path of the gmi2html.awk script, which is in the
 # same directory as this one.
@@ -50,7 +50,7 @@ for f in *.gmi **/*.gmi; do
   echo "processing: ${f} -> ${HTML_FILENAME}"
 
   # Run the gmi2html.awk script, passing in the parameters
-  awk -f $gmi2html -v $title -v $css -v $url \
+  awk -f $gmi2html -v $title -v $css -v $original \
     < $f \
     > $HTML_FILENAME
 done
@@ -18,19 +18,19 @@
 #   <in>: the folder of Gemini files to be converted
 #   <out>: the folder in which to put the generated HTML files
-#   <title>, <css>, <url>: parameters passed to gmi2html.awk; see gmi2html.awk for more details
+#   <title>, <css>, <original>: parameters passed to gmi2html.awk; see gmi2html.awk for more details
 #
 
0b1155b0dab9c0'>6e8f001c ^
1687e0f4 ^












b3d031a9 ^



6e8f001c ^
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42